package VMOMI::HealthUpdateInfoComponentType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
